﻿// Copyright (c) Strange Loop Games. All rights reserved.
// See LICENSE file in the project root for full license information.
// <auto-generated from VehicleTemplate.cs />

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.Components.VehicleModules;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Math;
    using Eco.Shared.Networking;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.Items;
    
    [Serialized]
    [LocDisplayName("Desert Buggy")]
    [Weight(25000)]
    [AirPollution(0.5f)]
    [Ecopedia("Crafted Objects", "Vehicles", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class MadMaxCarItem : WorldObjectItem<MadMaxCarObject>
    {
        public override LocString DisplayDescription { get { return Localizer.DoStr("The world is over, but the road never ends"); } }
    }


    [RequiresSkill(typeof(IndustrySkill), 2)]
    public partial class MadMaxCarRecipe : RecipeFamily
    {
        public MadMaxCarRecipe()
        {
            var recipe = new Recipe();
            recipe.Init(
                "Desert Buggy",  //noloc
                Localizer.DoStr("Desert Buggy"),
                new List<IngredientElement>
                {
                    new IngredientElement(typeof(GearboxItem), 2, typeof(IndustrySkill)),
                    new IngredientElement(typeof(SteelPlateItem), 10, typeof(IndustrySkill)),
                    new IngredientElement(typeof(LeatherHideItem), 10, typeof(IndustrySkill)),
                    new IngredientElement(typeof(CombustionEngineItem), 1, true),
                    new IngredientElement(typeof(RubberWheelItem), 4, true),
                    new IngredientElement(typeof(RadiatorItem), 1, true),
                    new IngredientElement(typeof(SteelAxleItem), 1, true),
                    new IngredientElement(typeof(IronPipeItem), 10, true),
                },
                new List<CraftingElement>
                {
                    new CraftingElement<MadMaxCarItem>()
                });
            this.Recipes = new List<Recipe> { recipe };
            this.ExperienceOnCraft = 18;
            this.LaborInCalories = CreateLaborInCaloriesValue(2000, typeof(IndustrySkill));
            this.CraftMinutes = CreateCraftTimeValue(typeof(MadMaxCarRecipe), 10, typeof(IndustrySkill));
            this.ModsPreInitialize();
            this.Initialize(Localizer.DoStr("Desert Buggy"), typeof(MadMaxCarRecipe));
            this.ModsPostInitialize();
            CraftingComponent.AddRecipe(typeof(RoboticAssemblyLineObject), this);
        }

        /// <summary>Hook for mods to customize RecipeFamily before initialization. You can change recipes, xp, labor, time here.</summary>
        partial void ModsPreInitialize();
        /// <summary>Hook for mods to customize RecipeFamily after initialization, but before registration. You can change skill requirements here.</summary>
        partial void ModsPostInitialize();
    }

    [Serialized]
    [RequireComponent(typeof(StandaloneAuthComponent))]
    [RequireComponent(typeof(FuelSupplyComponent))]
    [RequireComponent(typeof(FuelConsumptionComponent))]
    [RequireComponent(typeof(PublicStorageComponent))]
    [RequireComponent(typeof(MovableLinkComponent))]
    [RequireComponent(typeof(AirPollutionComponent))]
    [RequireComponent(typeof(VehicleComponent))]
    [RequireComponent(typeof(CustomTextComponent))]
    //[RequireComponent(typeof(ModularStockpileComponent))]
    [RequireComponent(typeof(TailingsReportComponent))]
    public partial class MadMaxCarObject : PhysicsWorldObject, IRepresentsItem
    {
        static MadMaxCarObject()
        {
            WorldObject.AddOccupancy<MadMaxCarObject>(new List<BlockOccupancy>(0));
        }

        public override TableTextureMode TableTexture => TableTextureMode.Metal;
        public override LocString DisplayName { get { return Localizer.DoStr("Desert Buggy"); } }
        public Type RepresentedItemType { get { return typeof(MadMaxCarItem); } }

        private static string[] fuelTagList = new string[]
        {
            "Liquid Fuel",
        };

        private MadMaxCarObject() { }

        protected override void Initialize()
        {
            base.Initialize();
            
            this.GetComponent<CustomTextComponent>().Initialize(200);
            //this.GetComponent<PublicStorageComponent>().Initialize(36, 8000000);
            this.GetComponent<FuelSupplyComponent>().Initialize(2, fuelTagList);
            this.GetComponent<FuelConsumptionComponent>().Initialize(40);
            this.GetComponent<AirPollutionComponent>().Initialize(0.5f);
            this.GetComponent<VehicleComponent>().Initialize(30, 0, 4);
            var storage = this.GetComponent<PublicStorageComponent>();
            storage.Initialize(18, 1000000);
            storage.Storage.AddInvRestriction(new NotCarriedRestriction());
            //this.GetComponent<StockpileComponent>().Initialize(new Vector3i(2,2,3));
        }
    }
}
